// *******************************************************************
// B_HOME14.POV                                             4 Dec 2002
// Beauty Shot of Modernist House: Across front looking west
// *******************************************************************

#version 3.5;

// *******************************************************************
// Control Variables: 
//    turning some of these off = many "not 2 objs in csg" messages
// *******************************************************************

#declare ShowDetails = 1;    // 0=some,   1=full 
#declare ShowLights  = 1;    // 0=day,    1=night
#declare ShowFloor   = 1;    // 0=hide,   1=show
#declare ShowGlass   = 1;    // 0=hide,   1=show
#declare ShowArch    = 1;    // 0=hide,   1=show
#declare DoorOpen    = 0;    // 0=closed, 1=open
#declare ShowRails   = 1;    // 0=hide,   1=show
#declare DayLight    = 1;    // 0=nite,   1=day
#declare ShowShrubs  = 1;    // 0=hide,   1=show

#include "m_home00.inc"      // declarations specific to Modernist_House

global_settings { assumed_gamma 1.0 
                  max_trace_level 8 }

// *******************************************************************
// LIGHTS! ( and Sky and Background )
// *******************************************************************

#if ( DayLight = 0 )
   background { color Black }             // nite
#else
   background { color LightBlue }         // day

   #declare LightLocate = < -70, 110, -150 >; //SW afternoon
   #declare intensity = 2;

   #if ( ShowDetails = 0 )
      light_source { LightLocate  color White }
   #else
      sky_sphere { pigment { Bright_AquaBlue4  
                             scale < 65, 2, 15 >
                           }//end pigmnt
                 }//end day sky
      light_source {
         < 0, 0, 0 >                      // position (translated below)
         color rgb 1.0                    // color
         area_light < 2,0,0 > < 0,0,2 >   // light's spread
         2, 2                             // total number of lights
         adaptive 0                       // 0,1,2,3... 
         jitter                           // random softening
         translate LightLocate            // location of light
         parallel                         // more sun-like effect
         point_at <0, 0, 0>               // target point
                } // end area light
   #end
#end

// *******************************************************************
// CAMERA!
// *******************************************************************

#declare Beauty_Shot =
camera {
//   direction < 0, 0, 2.85 >
   angle 49
   location  <  30, 5, -50 >           //in front of East Room
   look_at   < -25, 5, -10 > }         //looking toward West room    

// *******************************************************************
// *******************************************************************

#declare MoveX = 0; 
#declare MoveY = 0;
#declare MoveZ = -5;

camera { Beauty_Shot    translate < MoveX, MoveY, MoveZ > }

// *******************************************************************
// Describe the set:
// *******************************************************************

// *******************************************************************
// III.  DEFINE  Modernist_Home Components:
// *******************************************************************

// *******************************************************************
//       B.  North Room:
// *******************************************************************

//    DEFINE  the North Room:
#declare North_Room =
union {
   //roof:
   object { North_Roof scale < 1, 0.7, 1>  translate y*21 }

   //chimneys:
   object { Chimney_1  translate <  17, 15, -17 > } //south

   //north wall:
   object { N_North_Frame_Up  translate <   0.0, 16, 17.5 > } //1st floor
   object { N_North_Frame_Dn  translate < -17.5,  6, 17.5 > } //ground

   //south:
   object { N_South_Frame_East    translate <    20, 16, -17.5 > } //1st floor
   object { N_South_Frame_West    translate < -22.5, 16, -17.5 > } //1st floor
   object { N_South_Frame_East    translate <    20,  6, -17.5 > } //ground
   object { N_South_Frame_West    translate < -22.5,  6, -17.5 > } //ground
   object { N_South_Frame_Center  translate <    -5, 16,  -7.5 > } //1st floor
   //1st floor: west of chimney: french doors:
   object { N_South_Frame_Doors   translate <  9, 16, -17.5 > }

   //west:
   object { N_West_Frame  translate < -30, 16, 0 > } //1st floor
   object { N_West_Frame  translate < -30,  6, 0 > } //ground floor

   //east: select one or the other, NOT BOTH:
//   object { N_East_Frame    translate < 35, 16, 0 > } //1st floor
//   object { N_East_Railing  translate < 29, 13,  15.5 > } //1st floor

#if ( ShowDetails = 1 )
   //north wall:
   object { N_North_Panel_Up  translate <   0.0, 16, 17.5 > } //1st floor
   object { N_North_Panel_Dn  translate < -17.5,  6, 17.5 > } //ground

   //south wall:
   object { N_South_Panel         translate < -26,  6, -17.5 > } //both  
   object { N_South_Panel_Center  translate <  -5, 16,  -7.5 > } //1st floor

   //east wall:
//   object { Window_Dome_1      translate < 29, 11, 0 > } //1st floor
//   object { Window_Dome_Frame  translate < 29, 11, 0 > } //1st floor

   //west wall:
   object { N_West_Panel  translate < -30, 10, 0 > } //both floors

   //doors:
//   object { M_Front_Door rotate y*180 translate < 0, 6, 17 > }//north door
   object { M_Front_Door  translate < -5, 6, -12.5 > }//south door

   //stairs, railings:
   object { North_Stairs  translate < -10, 5.85, 5.5 > }

      #if ( ShowRails = 1 )
         //stair railings:
         object { Railing_Section_A ( 1.5, 0.25, 3 )
                     rotate y*90  translate <  -3.75, 13, 12 > } //east 
         object { Railing_Section_A ( 1.5, 0.25, 3 )
                     rotate y*90  translate < -16.25, 13, 12 > } //west
         object { Railing_Section_A ( 1.5, 0.25, 3 )
                                  translate < -16, 13, -0.5 > } //south
      #end //show railings?

#end  // show details?

   // floor:
   #if ( ShowFloor = 1 )
      object { Build_Block_1           // ground floor    
               texture { Brown_Tex }
               scale < 61, 1, 36 >  
               translate < 0, 1, 0 >
             }// end north ground floor

      #if ( ShowDetails = 1 )
         object { Build_Block_1           // 1st floor cntr rear
                  texture { Tan_Tex  }
                  scale < 11, 0.5, 6.5 >
                  translate < -10, 11, 14.25 >
                }// end north of stair
         object { Build_Block_1           // 1st floor:center front
                  texture { Tan_Tex }
                  scale < 11, 0.5, 10 >
                  translate < -10, 11, -3 >
                }// end 1st floor center
         object { Build_Block_1           // 1st floor:west
                  texture { Tan_Tex }
                  scale < 15.5, 0.5, 35 >
                  translate < -22, 11, 0 >
                }// end west part
         object { Build_Block_1           // 1st floor:center east
                  texture { Tan_Tex }
                  scale < 11.5, 0.5, 26 >
                  translate < 0, 11, 5 >
                }// end 1st floor center
         object { Build_Block_1           // 1st floor east
                  texture { Tan_Tex }
                  scale < 24.5, 0.5, 35 >
                  translate < 18, 11, 0 >
                }// end 1st floor east

     #end  // show details? loop

   #end // show floor?
      } // end north room union


// *******************************************************************
// *******************************************************************
//       C.  East Room:
// *******************************************************************

//    DEFINE East Wing:
#declare East_Room =
union {
   //roof:
   object { East_Roof scale < 1, 0.8, 1>  translate y*12 }

   //walls:
   object { E_South_Frame  translate < 0, 6,  37.5 > }//north
   object { E_South_Frame  translate < 0, 6, -37.5 > }//south
   object { E_West_Frame_N translate < -20, 6,  21 > }
   object { E_East_Frame   translate <  20, 6, -32 > }

   #if ( ShowDetails = 1 ) //show maximum
      //walls:
      object { E_North_Panel  translate <   0.0, 6,  37.5 > }//north
      object { E_South_Panel  translate <   0.0, 6, -37.5 > }//south
      object { E_East_Panel   translate <  20.0, 6,   0.0 > }
      object { E_West_Panel_S translate < -17.5, 5, -22.5 > }
      object { E_West_Panel_N translate < -20.0, 6,  27.0 > }
      #if ( ShowRails = 1 )
         //roof railings:
         object { Railing_Section_A ( 1.5, 0.25, 23 )
                     rotate y*90  translate < 20.5, 14, 35.5 > } //east 
         object { Railing_Section_A ( 1.5, 0.25, 11 )
                                  translate < -18.5, 14,  37.55 > } //north
         object { Railing_Section_A ( 1.5, 0.25, 11 )
                                  translate < -18.5, 14, -37.55 > } //south
      #end //show railings?
   #end  //of show all details?

   //floor:
   #if ( ShowFloor = 1 )
      object { Build_Block_1              
               texture { DarkWood_Tex }
               scale < 41, 1, 76 >
               translate < 0, 1, 0 >
             }// end east floor
   #end //if showfloor loop
      } // end east room union


// *******************************************************************
// *******************************************************************
//       D.  West Room: Kitchen:
// *******************************************************************

//    DEFINE West Room:
#declare West_Room =
union {
   //roof:
   object { West_Roof  translate < 0, 21, 0 > scale < 1, 0.6, 1 > }

   //walls: frames:
   object { W_South_Frame  translate < 0, 6, -12.5 > }
   object { W_North_Frame  translate < 0, 6,  12.5 > }
   object { W_West_Frame   translate < -15, 6, 0 > }
   object { W_East_Frame   translate <  15, 6, 0 > }

   #if ( ShowDetails = 1 )
      //walls: panels:
      object { W_North_Panel  translate < 0, 6,  12.5 > }
      object { W_South_Panel  translate < 0, 6, -12.5 > }
      object { W_West_Panel   translate < -15, 6, 0 > }
      object { W_East_Panel   translate <  15, 6, 0 > }
      //kitchen:
//      object { W_Kitchen      translate < 0, 0, 0 > }
      //door:
      object { DoorA1_Closed  translate < -12,  4, 12.5 > }
      object { Above_Door     translate < -12, 10, 12.5 > }
   #end  // of show details?

   //floor:
   #if ( ShowFloor = 1 )
      object { Build_Block_1
               scale < 31, 1, 26 >
               texture { Tan_Tex }
             }// end west floor
   #end //show floor?
      } // end west room union


// *******************************************************************
// *******************************************************************
//  IV.   a Modernist/International Style House:
// *******************************************************************
// *******************************************************************

//    DEFINE the whole building and setting:
#declare Modernist_Home =
union {

   object { North_Room }
   object { East_Room  translate <  25, 0.0,   0 > }
   object { West_Room  translate < -45, 0.5, -20 > }
   object { Front_SideWalk  translate < -5, 0, -27.5 > }
   object { Arched_Hall_1   translate < -5, 4, -27.5 > }

   #if ( ShowShrubs = 1 )
      #include "m_scape.inc"           // landscaping
      #include "fktr01.inc"            // fake plastic trees
      //near front door:
      object { Planter_Box_2  translate < -22.5, 0.25, -25 > }
      object { treex02  scale <1.2, 3, 1.2> translate < -22.5, 0, -25 > }
   #end

      } // end union modernist house

// *******************************************************************
// *******************************************************************
// ACTION!  Define The Scene:
// *******************************************************************

object { Modernist_Home }

// GROUND:
object { Clip_Floor }

// *******************************************************************
// *******************************************************************
//    Michael Brendan Hurley, SDE, Ltd.                 Winter 2002
// *******************************************************************
