// *******************************************************************
// M_Floor.INC                                                Nov 2002
// Floor Plank Macro Tests for House Projects
// *******************************************************************

// *******************************************************************
//    F.   Floors:           Floor macros:   WAY WAY TOO LONG RENDERS!
// *******************************************************************
//
//   DEFINE  a row of boards: each plank 4"x 2"y HowLong'z:
//           scale: 1 PoV unit = 1 US foot
//           Move_X,Y,Z = +axis offset per iteration
//           How Many = even numbers works smoother
//           How Long = length of board you want to see
//           Start Here = x of center of 1st board

#macro FloorPlanks_1
   ( Move_X, Move_Y, Move_Z, How_Many, How_Long, Start_Here )
union {
   //set variables:
   #local mySeed = seed(69);
   #local Cuts = 1;
   #local Count = 0;
   #local Move_It = false;   // don't move 1st, 3rd, 5th,...plank
   #local Half_Length = (How_Long/2);

   //run loop:
   #while ( Count < How_Many )
      //render a plank 4"x 2"y (HowLong')z:
      object {
         //create plank:
         box { < -Move_X, -Move_Y, -Half_Length > < Move_X, Move_Y, Half_Length > }
         //check to stagger planks +-z:
         #if ( Move_It = true )
            #local Move_Z = Move_Z + Half_Length;
            #local Move_It = false;
         #else  //move_it is false:
            #local Move_Z = Move_Z;
            #local Move_It = true;
         #end
         //position the plank:
         translate < (Start_Here+((Move_X*2)*Count)), Move_Y, Move_Z >
         //reset Z offset: get every other board back to center z
         #if (Move_It = false)
            #local Move_Z = Move_Z - Half_Length;
//            #local texture { Blue_Tex } //debugging marker
         #else
            #local Move_Z = Move_Z;
//            texture { Red_Tex } //debugging marker
         #end
         //texture the plank:
         texture { RosewoodB
                   scale < 1, 1, 2 >
                   translate y*Cuts
                   translate z*0.5
                   rotate x*(1.5/(Count+0.1))
                 }//end tex
             }// end plank obj
      //update variables:
      #local Cuts = Cuts + ( 0.7 + rand (mySeed) );
      #local Count = Count + 1;
   #end  // end while loop
     } // union of planks
#end // floor macro

// **************************************************************

//    DEFINE  a whole room of flooring units:
#macro Whole_Floor_1 (
   Move_X,      // half board width of a 2x4
   Move_Y,      // half board height of a 2x4
   Move_Z,      // initial z-axis offset
   How_Many,    // ((How_Many)*(Move_X*2)) = width of room
   How_Long,    // length of 1 board in feet (& POV units)
   Start_Here,  // sets left edge of 1st plank at x = 0
   Offset_Z,    // move successive sets +z, equals (How_Long/2)
   Room_Depth,  // z-axis iterations to fill depth of room
   Clip_X,      // +x width of room
   Clip_Z       // +z depth of room
                     )
union {
   //initialize variables:
   #local Not_There_Yet = 0;
   //run loop:
   #while ( Not_There_Yet <= Room_Depth )
      object { FloorPlanks_1
               ( Move_X, Move_Y, Move_Z, How_Many, How_Long, Start_Here )
               translate z*((Offset_Z)*(Not_There_Yet))
               clipped_by {     //the edges of room:
                  box { < 0, -1, 0 > < Clip_X, 1, Clip_Z > } }//end clipping
              }//end floor plank obj
      //update variables:
      #local Not_There_Yet = Not_There_Yet + 1;
   #end  //while loop
      } // end union whole floor #1
#end  // macro whole floor 1

*/

// ************************************************************************
// Michael Brendan Hurley   ShadowDancer Enterprizes, Ltd.    Winter 2002
// ************************************************************************