// *******************************************************************
// M_HOME00.INC                                Winter 2000-Winter 2002
//             Definitions of basic objects and effects         
//             for     Modernist_House      version 2.0
// *******************************************************************
//
// INClude File "Sub-Contractors":
//
// RoundBox.inc for POV 3.0 and above
// (c) Philip Cowley ( philip.cowley@totem.co.uk ) 13/07/97
// used for walls and roofs
//
//Fake Plasteek Trees 1.0  for POV-Ray 3.1
//Simple, non-realistic, fast rendering trees
//Luis Valoyes / Bogota / Colombia
//www.luisvaloyes.uni.cc  ( luisvaloyes@malditasea.zzn.com )
//
// *******************************************************************

// *******************************************************************
// *******************************************************************
// I.    DEFINE Includes, Constants and Conditionals:
// *******************************************************************
// *******************************************************************

#version 3.5; 

#include "brendan.inc"                 // universal scene objects
                                       // and calls to support INC's

//if not defined in calling .pov file, default value=false|off|no: 
#ifndef ( ShowDetails )
   #declare ShowDetails = 0;    // 0=minimum detail, 1=full detail
#end
#ifndef ( GridOn )
   #declare GridOn      = 0;    // 0=off, 1=on
#end
#ifndef ( ShowLights )
   #declare ShowLights  = 0;    // 0=day, 1=night
#end
#ifndef ( ShowFloor )
   #declare ShowFloor   = 0;    // 0=no, 1=yes
#end
#ifndef ( ShowGlass )
   #declare ShowGlass   = 0;    // 0=no, 1=yes
#end
#ifndef ( ShowArch )
   #declare ShowArch    = 0;    // 0=no, 1=yes
#end
#ifndef ( DoorOpen )
   #declare DoorOpen    = 0;    // 0=closed, 1=open
#end
#ifndef ( ShowRails )
   #declare ShowRails   = 0;    // 0=hide, 1=show
#end
#ifndef ( DayLight )
   #declare DayLight    = 1;    // 0=no,   1=yes
#end
#ifndef ( ShowShrubs )
   #declare ShowShrubs  = 0;    // 0=hide,   1=show
#end

// *******************************************************************
// *******************************************************************
// II.     DEFINE Structural Components
// *******************************************************************
// **************************************************************
//    A.   1. Basic Objects
// **************************************************************

//    DEFINE  generic scalable building block: 1x 1y 1z:
#declare Build_Block_1 =
box { <-0.5, -0.5, -0.5>  <0.5, 0.5, 0.5> }

// **************************************************************

//   DEFINE   A square box: clipped into triangle
#declare Pane_Tri_1 =
intersection {
   object { UnitBox  scale < 0.5, 0.5, 0.01 > }
   plane  { y, 0     rotate z*135 } //end plane
             } // end  triangle pane 1

// **************************************************************
//    2. Arches:
// **************************************************************

#declare Arch_Z1 =                     // 0.3 thick
difference {
   object { Disk_Z  scale < 1.0, 1.0, 1.0 > } 
   object { Disk_Z  scale < 0.7, 0.7, 1.1 > }
   clipped_by { plane { -y, 0 } }
           } // end Arch_Z 1

// **************************************************************

#declare Arch_Z2 =                     // 0.05 thick
difference {
   object { Disk_Z  scale <  1.0,  1.0, 1.0 > }
   object { Disk_Z  scale < 0.95, 0.95, 1.1 > }
   clipped_by { plane { -y, 0 } }
           } // end Arch_Z 2

// **************************************************************

//    DEFINE   a large THIN arch/roof/barrel dome:
#declare BigArch_2 =
object { Arch_Z2  scale < 10, 9.5, 5 > } // end big arch v.2

// **************************************************************

//    DEFINE  Interior of frame has rounded corners: roundbox.inc cut-out
#declare ArchWay_1 =
   difference {
      union {
         object { CubeY1
                  scale < 4, 9.5, 4 >  translate x*-4.5 } // end left
         object { CubeY1
                  scale < 4, 9.5, 4 >  translate x*4.5  } // end right
         object { CubeX1
                  scale < 11, 4, 4 >  translate y*5 } // end top
            }//end frame union
      object {
         #declare RB_P1 = <  4.5,  4.5,  5 >;
         #declare RB_P2 = < -4.5, -4.5, -5 >;
         #declare RB_Thickness = 2;   
         #declare RB_Solid = 0;
         #include "roundbox.inc"
         translate < 0, -0.25, 0 >
             } //end roundbox cut-out
              } // end difference arch way 1

// **************************************************************
//    3. Stairs                                                     
// **************************************************************

//    DEFINE   a set of stairs:
#declare North_Stairs =
union { 
   object { Pane_Tri_1 
               scale < 13, 13, 10 >
               rotate y*-90  //long edge face front
               rotate x*90   //tilt long edge toward back
               translate < -4, -1, -1 >
          }// end triangle stair support
   object { Pane_Tri_1 
               scale < 13, 13, 10 >
               rotate y*-90  //long edge face front
               rotate x*90   //tilt long edge toward back
               translate < 4, -1, -1 >
          }// end triangle stair support

   #declare sz = 5;
   #declare sy = 5;
   #declare Offset = 0.7;
   #declare Looper = 0;
   #while ( Looper <= 14)
      object { CubeX1
               scale < 10, 1.6, 2 >
               translate < 0, sy, sz >
               texture { T_Stone2  scale < 15, 5, 1 > }
             }// end step
      #declare sy = sy - Offset;
      #declare sz = sz - Offset;
      #declare Looper = Looper + 1;
   #end
   //back panel: utility closet
   union {
      object { CubeX1
               scale < 8, 22, 1 >
               translate < 0, 0, 5 >
               texture { T_Wood2  scale < 5, 15, 1 > }
             }//end door
   object { sphere { <0, 0, 0>  0.25 }
            translate < -1, -1, -3.5 >
            texture { Bright_Bronze }
          }//end knob
         }// end union closet door
      } // end union stair block

// **************************************************************
//    4. Railing/banister:
// **************************************************************

//    DEFINE  generic scalable cylinder with spherical ends:
#macro Round_Post_Y ( Post_Size_Y , Post_Size_X )
union {
   cylinder { Post_Size_Y*y, -(Post_Size_Y)*y, Post_Size_X open }//end cyl
   sphere { < 0,  Post_Size_Y, 0 >  Post_Size_X }//end top ball
   sphere { < 0, -Post_Size_Y, 0 >  Post_Size_X }//end bottom ball
      } // end union scalable post
#end // macro for y pillar

// **************************************************************

//    DEFINE  scalable banisters/fensing/frames:
//            base post centered at <0,0,0>
//            other posts, railings translated +x +y

#macro Railing_Section_A ( How_Tall, How_Wide, How_Many )
   //declare local variables:
   #local Post_Size_Y = How_Tall; //duh...?
   #local Post_Size_X = How_Wide; //circumferance
   #local How_Many    = How_Many; //
   //call macro:
   union {
      #local P_Count = 0;
      #while ( P_Count <= How_Many )
         object {            
            Round_Post_Y ( Post_Size_Y , Post_Size_X )//end macro call
            translate < (P_Count*(How_Tall*2)), 0, 0 >
            #if ( ShowDetails = 0 )
               texture { Yellow_Tex }
            #else
               texture { Bright_Bronze }
            #end
                }//end all posts
         object {
            Round_Post_Y ( Post_Size_Y , Post_Size_X )//end macro call
            rotate z*90
            translate < (P_Count*(How_Tall*2)+How_Tall), (How_Tall), 0 >
            #if ( ShowDetails = 0 )
               texture { Blue_Tex }
            #else
               texture { Bright_Bronze }
            #end
                }//end railings
         #if ( P_Count = How_Many )
            object {           //last post:
               Round_Post_Y ( Post_Size_Y , Post_Size_X )//end macro call
               translate < (P_Count*(How_Tall*2))+(How_Tall*2), 0, 0 >
               #if ( ShowDetails = 0 )
                  texture { Red_Tex }
               #else
                  texture { Bright_Bronze }
               #end
                   }//end add last post
         #end
         #declare P_Count = ( P_Count + 1 );
      #end //while loop
         } // end union scalable railing
 #end // macro for railing section

// **************************************************************

//    DEFINE a sidewalk/driveway:
#declare Front_SideWalk =
object { Build_Block_1
         scale < 22, 1, 43 >
         texture { T_Stone2  scale < 1.2, 1, 7 > }
       } // end sidewalk

// **************************************************************

//    DEFINE a sidewalk/driveway:
#declare Rear_SideWalk1 =
object { Build_Block_1
         scale < 9, 1, 26 >
         texture { T_Stone2  scale < 1.3, 1.1, 9 > }
       } // end sidewalk

// **************************************************************
//    B.   Frames: Single: Wall:
// **************************************************************

//   DEFINE   a frame 10x / 10y units
#declare Frame_A =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -5,  0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  5,  0, 0 > }
   object { CubeX1
            scale < 10.5, 1, 1 >  translate < 0,  5, 0 > }
   object { CubeX1
            scale < 10.5, 1, 1 >  translate < 0, -5, 0 > }
      } // end Frame A

// **************************************************************

//    DEFINE  rotated frame:
#declare rotated_Frame_A =
object { Frame_A  rotate y*90 }

// **************************************************************

//   DEFINE   a frame 10x / 10y units: thicker beams:
#declare Frame_A2 =
union {
   object { CubeY1
            scale < 1.25, 10.0, 1.25 >  translate < -5, 0, 0 > }
   object { CubeY1
            scale < 1.25, 10.0, 1.25 >  translate <  5, 0, 0 > }
   object { CubeX1
            scale < 10.5, 1.25, 1.25 >  translate < 0,  5, 0 > }
   object { CubeX1
            scale < 10.5, 1.25, 1.25 >  translate < 0, -5, 0 > }
      } // end Frame A2

// **************************************************************
/*
//   DEFINE   a half-height frame 10x 5y units
#declare Frame_B =
union {
   object { CubeY1                                         
            scale <  1, 5, 1 >  translate < -5, 0, 0 > }
   object { CubeY1                                         
            scale <  1, 5, 1 >  translate <  5, 0, 0 > }
   object { CubeX1                                        
            scale < 10.25, 1, 1 >  translate < 0,  2.5, 0 > }
   object { CubeX1                                        
            scale < 10.25, 1, 1 >  translate < 0, -2.5, 0 > }
      } // end Frame B
*/
// **************************************************************
/*
//   DEFINE   a quarter-height frame 10x 2.5y units
#declare Frame_C =
union {
   object { CubeY1                                         
            scale < 1, 2.75, 1 >  translate < -5, 0, 0 > }
   object { CubeY1                                          
            scale < 1, 2.75, 1 >  translate <  5, 0, 0 > }
   object { CubeX1                                        
            scale < 10, 1, 1 >  translate < 0,  1.25, 0 > }
   object { CubeX1                                        
            scale < 10, 1, 1 >  translate < 0, -1.25, 0 > }
      } // end Frame C
*/
// **************************************************************
/*
//   DEFINE   half-wide frame unit 5x 10y 0.5z:
#declare Frame_D =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -2.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  2.5, 0, 0 > }
   object { CubeX1
            scale < 5, 1, 1 >  translate < 0, -5, 0 > }
   object { CubeX1
            scale < 5, 1, 1 >  translate < 0,  5, 0 > }
      } // end Frame D
*/
// **************************************************************

//   DEFINE   thicker version of D, 5x 10y 1z:
#declare Frame_D2 =
union {
   object { CubeY1
            scale < 1, 10, 2 >  translate < -2.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 2 >  translate <  2.5, 0, 0 > }
   object { CubeX1
            scale < 5.5, 1, 2 >  translate < 0, -5, 0 > }
   object { CubeX1
            scale < 5.5, 1, 2 >  translate < 0,  5, 0 > }
      } // end Frame D 2

// *******************************************************************
//    C.   Frames: Single: Window:
// *******************************************************************

// *******************************************************************
//    D.   Panels: Single: Wall:
// *******************************************************************

//    DEFINE  a 10.5x 12y 1z panel:
//#declare Panel_A =
//object { UnitBox  scale < 5.25, 6, 0.5 > } // end panel a

// **************************************************************

//    DEFINE  a 10.5x 5.5y 1z panel:
//#declare Panel_B =
//object { UnitBox  scale < 5.25, 2.75, 0.5 > } // end panel b

// **************************************************************

//    DEFINE  a 10.5x 2.5y 1z panel:
//#declare Panel_C =
//object { UnitBox  scale < 5.25, 1.25, 0.5 > } // end panel c

// **************************************************************

//    DEFINE  a 6.5x 10y 1z panel:
#declare Panel_D1 =
object { UnitBox  scale < 3.25, 5, 0.5 > } // end panel d

// **************************************************************

//    DEFINE  a 7x 12y 1z panel:
#declare Panel_D2 =
object { UnitBox  scale < 3.5, 6, 0.5 > } // end panel d

// **************************************************************

//    DEFINE  a 5.5x 5.5y 1z panel:
//#declare Panel_E =
//object { UnitBox  scale < 2.75, 2.75, 0.5 > } // end panel e

// **************************************************************

//    DEFINE  a 5.5x 2.5y 1z panel:
//#declare Panel_F =
//object { UnitBox  scale < 2.75, 1.25, 0.25 > } // end panel f

// **************************************************************
//    E.   Panels: Single: windows:
// **************************************************************

//   DEFINE   a 1-unit square window glass pane:
#declare Pane_Square_2 =
object { UnitBox
         scale < 0.5, 0.5, 0.01 >
         #if ( ShowDetails = 0 )
            texture { Red_Tex }
         #else
            texture { T_Glass1 }
         #end
       } // end square glass pane

// **************************************************************
//    F.   Floors:    Floor macros: WAY WAY TOO LONG TO RENDER!
// **************************************************************
//
//#include "m_floor.inc"
//
// **************************************************************
//    G. Lamps and Light Fixtures:
// **************************************************************

//   DEFINE  an object for a light source
#declare Flat_Light =
object {
   box { < -0.5, -0.1, -0.5 > < 0.5, 0.1, 0.5 >
         texture { Gray_Tex }
         finish { Luminous }
         hollow
       } // end box of glass
       } // end obj flat light

// **************************************************************

//   DEFINE  a cylinder light fixture, for stove: ON:
#declare Lamp_A_On =
light_source {
   < 0, 0, 0 >
   color White
   looks_like { Flat_Light }
   spotlight
   cylinder
   point_at < 0, -1, 0 >
   radius 55
   tightness 25
   falloff 58
   fade_distance 7
   fade_power 2
             } // end light source

// **************************************************************

//   DEFINE  a light fixture: for stove: OFF:
#declare Lamp_A_Off =
object {
   box { < -0.5, -0.1, -0.5 > < 0.5, 0.1, 0.5 >
         texture { T_Glass1 }
         hollow
       } // end box of glass
       } // end object

// **************************************************************

//   DEFINE  an area light fixture: for rooms: ON:
#declare Lamp_B =
light_source {
   < 0, 0, 0 >
   color White
   looks_like { Flat_Light }
   fade_distance 7
   fade_power 2
             } // end light source  

// **************************************************************

//   DEFINE  a spotlight fixture: for rooms: ON:
#declare Lamp_B2 =
light_source {
   < 0, 0, 0 >
   color White
   looks_like { Flat_Light }
  spotlight               // this kind of light source
  point_at <0, -5, 0>      // direction of spotlight
  radius 15                // hotspot (inner, in degrees)
  tightness 10            // tightness of falloff (1...100) lower is softer, higher is tighter
  falloff 28               // intensity falloff radius (outer, in degrees)
             } // end light source  

// **************************************************************

//    DEFINE   an object as a light source
#declare Globe_Light =
object {
   sphere { < 0, 0, 0 > 0.5
      #if ( ShowDetails = 0 )
         texture { White_Tex }
      #else
         texture { T_Glass1 }
         finish { Luminous }
      #end
      hollow
          } // end sphere of glass
       } // end obj Globe Light

// **************************************************************
// **************************************************************

//   DEFINE   A Wall Lamp, facing south, -z:   light source on:
#declare WallLamp_A =
union {
   object {
      UnitBox                           // lamp base
      texture { T_Wood2 }
      scale < 1, 1, 0.25 >
      translate < 0, 0, 0.5 >        
          } //end object Lamp Base
   light_source {                      // sphere as light bulb
      < 0, 0, 0 >
      color White
      looks_like { Globe_Light }
      fade_distance 10
      fade_power 2
                } // end light source  
      } // end union Wall Lamp A

// **************************************************************

//   DEFINE   A Wall Lamp, facing south, -z:   light source off
#declare WallLamp_B =
union {
   object {
      UnitBox                           // lamp base
      texture { T_Wood2 }
      scale < 1, 1, 0.25 >
      translate < 0, 0, 0.5 >        
          } //end object Lamp Base
   object { Globe_Light 
          }//end sphere
      } // end union Wall Lamp B

// **************************************************************

//   DEFINE   A Wall Lamp   cylinder light source on
#declare WallLamp_C =
union {
   object {
      UnitBox                           // lamp base
      texture { T_Wood2 }
      scale < 1, 0.25, 1 >
      translate < 0, 0.5, 0 >        
          } //end object Lamp Base
   light_source {                      // sphere as light bulb
      < 0, 0, 0 >
      color White
      cylinder
      looks_like { Globe_Light }
      radius 30
      falloff 15
      tightness 15
      point_at < 0, -10, 0 >
      fade_distance 15
      fade_power 2
      media_attenuation on
                } // end light source
    hollow
      } // end union Wall Lamp C

// **************************************************************

//   DEFINE   A Wall Lamp   cylinder light source off
#declare WallLamp_D =
union {
   object {
      UnitBox
      texture { T_Wood2 }
      scale < 1, 0.25, 1 >
      translate < 0, 0.5, 0 >        
          }//end object Lamp Base
   object { Globe_Light }// end light bulb
      } // end union Wall Lamp D

// **************************************************************
//    H.   Doors:
// **************************************************************

//   DEFINE   basic door frame inset for 10x 10y Frame_A
#declare Frame_Door_A1 =
union {
   object { CubeY1                                        
            scale < 1.5, 8, 1.5 >  translate < -2.25, -1, 0 > }
   object { CubeY1                                       
            scale < 1.5, 8, 1.5 >  translate <  2.25, -1, 0 > }
   object { CubeX1                                        
            scale < 10, 1.5, 1.5 >  translate < 0, 3, 0 > }
   #if ( ShowDetails = 0 )
      texture { Blue_Tex }
   #else
      texture { T_Wood2 }
   #end
      } // end Frame for Door  A1

// **************************************************************

//   DEFINE  a 4x 7y door: CLOSED
#declare DoorA1_Closed =
union {
   difference {
      object { UnitBox
               scale < 2, 3.8, 0.10 >
             }//end main panel
      object { UnitBox
               scale < 1.25, 0.4, 1 >
               translate y*1
             }//end cut-out bottom
      object { UnitBox
               scale < 1, 0.3, 1 >
               translate < 0.25, 2.1, 0 >
             }//end cut-out
      object { UnitBox
               scale < 0.75, 0.2, 1 >
               translate < 0.5, 3, 0 >
             }//end cut-out
               #if ( ShowDetails = 0 )
                  texture { Gray50_Tex }
               #else
                  texture { EMBWood1  scale < 2, 11, 2 > }
               #end
              }//end difference
   object { UnitBox 
            scale < 1.4, 1.65, 0.02 >
            translate < 0, 1.9, 0 > 
            #if ( ShowDetails = 0 )
               texture { Black_Tex }
            #else
               #if ( ShowGlass = 0 )
                  texture { Black_Tex }
               #else  
                  texture { T_Glass1 }
               #end
            #end
          } //end window glass
   object { sphere { <0, 0, 0>  0.25 }
            translate < -1.5, -0.5, -0.19 >
            #if ( ShowDetails = 0 )
               texture { Yellow_Tex }
            #else
               texture { Bright_Bronze }
            #end
          }//end knob
      }//end union door 1a closed

// **************************************************************

//   DEFINE  a 4x 7y door: OPEN
#declare DoorA1_Open =
object { DoorA1_Closed
         rotate y*-45
         translate < -0.75, 0, -1.5 >
       } // end Door A1 open

// **************************************************************

//    DEFINE  a 4x 7y door, plain: CLOSED:
#declare DoorA2 =
box { < 1.5, 3.5, 0.1 > < -1.5, -3.5, -0.1 >
      #if ( ShowDetails = 0 )
         texture { Gray50_Tex }
      #else
         texture { EMBWood1  scale < 3, 12, 1 > }
      #end
    }//end door A2

// **************************************************************

//   DEFINE  set of solid wall panels scaled for Door_Front
#declare Panel_Door_A1 =
union {
   object { UnitBox
            scale < 10, 1.2, 1.0 >  translate < 0, 4, 0 >
            #if ( ShowDetails = 0 )
               texture { Brown_Tex }
            #else
               texture { T_Stone15 }
            #end
          }//upper brick panel
   object { UnitBox
            #if ( ShowDetails = 0 )
               texture { Black_Tex }
            #else
               texture { T_Glass1 }//end textr
            #end      
            scale < 1.5, 4, 0.1 >  translate < -3.5, -1, 0 > 
          }//left glass
   object { UnitBox
            #if ( ShowDetails = 0 )
               texture { Black_Tex }
            #else
               texture { T_Glass1 }//end textr
            #end      
            scale < 1.5, 4, 0.1 >  translate <  3.5, -1, 0 > 
          }//right glass
      } // end Panels New Door A1

// **************************************************************

//    DEFINE  a front door:
#declare M_Front_Door =
union {
   //frames & panels:
   object { Frame_A2
            #if ( ShowDetails = 0 )
               texture { Red_Tex }
            #else
               texture { T_Wood2  scale < 1, 5, 1 > }
            #end
          } //south front frame
   object { Panel_Door_A1 } //south front panels
   //door:
   object { Frame_Door_A1 } // door jams
   #if ( DoorOpen = 0 )
      object { DoorA1_Closed  translate y*-1.2 }
   #else
      object { DoorA1_Open  translate y*-1.2 }
   #end
      }//end door union

// **************************************************************

//    DEFINE a plain transome above door:
#declare Above_Door =
object {
   #declare RB_P1 = <  3.5,  2.5,  1.01 >; // right upper rear corner
   #declare RB_P2 = < -3.5, -2.5, -1.01 >; // left lower front corner
   #declare RB_Thickness = 2;      
   #declare RB_Solid = 1;          
   #include "roundbox.inc"
   #if ( ShowDetails = 0 )
      texture { Red_Tex }
   #else
      texture { T_Stone15 scale < 5, 1.5, 1.5 > }
   #end
       }// end above door transome

// **************************************************************
// **************************************************************


//  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>     <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
// *******************************************************************
// *******************************************************************
//
//    NOTE THIS: All declarations above this point are of 
//               free-standing objects centered on <0,0,0>
//               that may be transformed for use in ANY scene.
//               The objects below are written and transformed
//               for THIS scene only.
//
// *******************************************************************
// *******************************************************************
//  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>     <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<


// *******************************************************************
// III.  DEFINE  Modernist_Home Components:
// *******************************************************************
// **************************************************************
//       A.  Specialized Components:
// **************************************************************

//    DEFINE  front hall with arched roof: 20x 20y 40z:
#declare Arched_Hall_1 =
union {
   #declare Move_Count = 1;       // start count
   #declare From_Z = -25;         // from where? >>REQUIRES HARD CODING<<
   #declare Move_It = +10;        // how far? 
   #declare Max_Count = 4;        // how many?

   #if ( DayLight = 0 )
      object { WallLamp_A  translate <  10, 9, (From_Z + 3.75) > }//globe lamp
      object { WallLamp_A  translate < -10, 9, (From_Z + 3.75) > }//globe lamp
   #else
      object { WallLamp_B  translate <  10, 9, (From_Z + 3.75) > }//globe lamp
      object { WallLamp_B  translate < -10, 9, (From_Z + 3.75) > }//globe lamp
   #end

   #while ( Move_Count <= Max_Count )
      object { ArchWay_1
               rotate < 0, 90, 0 >
               translate < 10, 1, (From_Z + Move_It) >
               #if ( ShowDetails = 0 )
                  texture { Green_Tex }
               #else
                  texture { T_Wood2  scale < 1, 5, 1 > }
               #end
             }// end rounded wall archs east
     object { ArchWay_1
              rotate < 0, 90, 0 >
              translate < -10, 1, (From_Z + Move_It) >
              #if ( ShowDetails = 0 )
                 texture { Yellow_Tex }
              #else
                 texture { T_Wood2  scale < 1, 5, 1 > }
              #end
            }// end rounded wall archs west

      #if ( ShowArch = 1 )   //display entry barrel roof
         //the frames:
         object { Arch_Z2 
                  scale < 10, 9.5, 1 >
                  translate < 0, 7.0, (From_Z + (Move_It/2)) >
                  #if ( ShowDetails = 0 )
                     texture { Red_Tex }
                  #else
                     texture { T_Wood2  scale < 1, 5, 1 > }
                  #end
                }// end arch frames
         //the lights:
         #if ( DayLight = 0 )
            object { WallLamp_C  translate < 0, 15, (From_Z + (Move_It/2)) > }
         #else
            object { WallLamp_D  translate < 0, 15, (From_Z + (Move_It/2)) > }
         #end
/*
         //skip northmost section
         #if ( Move_Count = Max_Count )
            object { BigArch_2 
                     translate < 0, 7.0, ((From_Z+1) + Move_It) >
                     #if ( ShowDetails = 0 )
                        texture { Black_Tex }
                     #else
                        texture { T_Glass1 }
                     #end // texture choices
                   }//end barrel roof
         #end // if < Max Count
*/
      #end // if Show Arch
      #declare From_Z = ( From_Z + Move_It ); 
      #declare Move_Count = Move_Count + 1;
   #end//of while loop
      } // end union arched hallway

// **************************************************************
//    Special windows:
// **************************************************************
                                             
//    DEFINE  a long quasi-cylinder window:  
#declare Window_Dome_1 =
difference {
   object {
      difference {
         object { Disk_Z  scale <  1.0,  1.0, 1.0 > }
         object { Disk_Z  scale < 0.95, 0.95, 1.1 > }
         clipped_by { plane { -y, 0 } }
                 } // end diff of disks
      scale < 9, 10, 17 >
      texture { T_Glass1 }
          }//end obj z-axis quarter cyl
   plane { x, 1  hollow on }
           } // end difference cyl window

// **************************************************************

//    DEFINE  a single quarter arch:
#declare Window_Dome_Arch =
difference {
   object { Arch_Z2  scale < 9, 10, 0.25 > }//end arch
   plane { y, 0  hollow on }
   plane { x, 0  hollow on }
   texture { T_Wood2  scale < 1, 5, 1 > }
           } // end difference domed arch

// **************************************************************

//    DEFINE  a set of quarter arches:
#declare Window_Dome_Frame =
union {
   object { Window_Dome_Arch  translate < 0, 0,  17.0 > }
   object { Window_Dome_Arch  translate < 0, 0,   7.5 > }
   object { Window_Dome_Arch  translate < 0, 0,  -7.5 > }
   object { Window_Dome_Arch  translate < 0, 0, -17.0 > }
      } // end dome frame

// **************************************************************
//    specialized components, con't...
// **************************************************************

// *******************************************************************
//       B.  North Room:
// *******************************************************************

//    DEFINE  north room roof:
#declare North_Roof =
union {
   object {
      #declare RB_P1 = < 8.5,  1.05,  23 >; // right upper rear corner
      #declare RB_P2 = < -13, -1.05, -23 >; // left lower front corner
      #include "roundbox.inc"               // calls file
      translate < -23, 0, 0 > 
          } // end west section roof
   object {
      #declare RB_P1 = <  12,  1.05, 23 >;
      #declare RB_P2 = < -12, -1.05, -9 >;
      #include "roundbox.inc"
      translate < -5, 0, 0 > 
          } // end center section roof
   object {
      #declare RB_P1 = <  17,  1.05,  23 >;
      #declare RB_P2 = < -14, -1.05, -23 >;
      #include "roundbox.inc"
      translate < 18, 0, 0 > 
          } // end east section roof
   texture { T_Stone24  scale < 4, 2, 1.5 > }      
      } // end north roof union

// **************************************************************

//    DEFINE  north room chimneys:
#declare Chimney_1 =
union  {
   difference {
      object { Build_Block_1
               scale < 12, 29, 4.5 >
               translate < 0, 0, 0 > }//body
      object { Build_Block_1
               scale < 8, 4.5, 4 >
               translate < 0, -10.5, 3.5 > }//fireplace cutout
     #if ( ShowDetails = 0 )
        texture { pigment { Firebrick } }
     #else
        texture { T_MBH_Brick_1  scale < 0.80, 0.80, 0.80 > }
     #end
              }// end difference chimney

   object { PostY1
            scale < 3, 2, 3 >
            translate < 3.5, 15.5, 0 >
            texture { Black_Tex }
          }// end flue
   object { PostY1
            scale < 3, 2, 3 >
            translate < 0, 15.5, 0 >
            texture { Black_Tex }
          }// end flue
   object { PostY1
            scale < 3, 2, 3 >
            translate < -3.5, 15.5, 0 >
            texture { Black_Tex }
          }// end flue
   object { Build_Block_1
            scale < 14, 1.5, 6 >
            translate < 0, 14.5, 0 >
            texture { Gray95_Tex }
          }// end cap
   object { Build_Block_1
            scale < 11, 1, 2 >
            translate < 0, -8, 2.5 >
            texture { Gray95_Tex }
          }// end mantle
   object { Build_Block_1
            scale < 14.5, 1.75, 8 >
            translate < 0, -14, 1.25 >
            texture { Gray95_Tex }
          }// end footer
       }// end chimney 1 union

// **************************************************************

//    DEFINE  north room: north wall frame: 1st floor:
#declare N_North_Frame_Up =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -29.5, 0, 0 > }//w
   object { CubeY1
            scale < 1, 10, 1 >  translate < -23.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate < -12.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  12.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  22.5, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  29.5, 0, 0 > }//e
   object { CubeX1
            scale < 59.5, 1, 1 >  translate < 0,  5, 0 > }//top
   object { CubeX1
            scale < 59.5, 1, 1 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end

      } // end north frames up stairs

// **************************************************************

//    DEFINE  north room: north wall upper panels:
#declare N_North_Panel_Up =
union {
   object {
      difference {
      object {
         #declare RB_P1 = <  31,  6.0,  1.1 >; // right upper rear corner
         #declare RB_P2 = < -31, -6.0, -1.1 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end main panel
      object {
         #declare RB_P1 = <  4.5,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -4.5, -4.0, -2.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end center cut-out
      object {
         #declare RB_P1 = <  -8,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -27, -4.0, -2.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end left cut-out
      object {
         #declare RB_P1 = < 27,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = <  8, -4.0, -2.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end right cut-out
                 }// end difference
            #if ( ShowDetails = 0 )
               texture { Coral_Tex }
            #else
               texture { T_Stone15 scale < 5, 1.5, 1.5 > }         
            #end
          } // end obj
   #if ( ShowGlass = 1 )
      object { Pane_Square_2  scale < 56, 10, 0.05 > }
   #end
      } // end north panels up stairs

// **************************************************************

//    DEFINE  north room: north wall lower frame:
#declare N_North_Frame_Dn =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -12.5, 0, 0 > }//w
   object { CubeY1
            scale < 1, 10, 1 >  translate <  -6.0, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <   5.0, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  12.5, 0, 0 > }//e
   object { CubeX1
            scale < 25.5, 1, 1 >  translate < 0,  5, 0 > }//top
   object { CubeX1
            scale < 25.5, 1, 1 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end

      } // end north frames down stairs

// **************************************************************

//    DEFINE  north room: north wall lower panels:
#declare N_North_Panel_Dn =
union {
   object {
      difference {
      object {
         #declare RB_P1 = <  13.0,  6.0,  1.1 >; // right upper rear corner
         #declare RB_P2 = < -13.5, -6.0, -1.1 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  10.0,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -10.0, -4.0, -2.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end left cut-out
                 }// end difference
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Stone15 scale < 5, 2, 1.5 > }
   #end
          } // end panel w/hole obj
   #if ( ShowGlass = 1 )
      object { Pane_Square_2  scale < 21, 11, 0.05 > }
   #end
      } // end north wall panels, down stairs

// **************************************************************

//    DEFINE  north room: south wall, east frame:
#declare N_South_Frame_East =
union {
/*    >>>>subsitute french doors here:
   object { CubeY1
            scale < 1, 10, 1 >  translate < -10.5, 0, 0 > }//w
   object { CubeY1
            scale < 1, 10, 1 >  translate <  -3.5, 0, 0 > }//w
   object { CubeX1
            scale < 7.5, 1, 1 >  translate < -7.0,  5, 0 > }//wtop
   object { CubeX1
            scale < 7.5, 1, 1 >  translate < -7.0, -5, 0 > }//wbot
*/
   //south chimney goes between these and above:
   object { CubeY1
            scale < 1, 10, 1 >  translate <  3, 0, 0 > }//e
   object { CubeY1
            scale < 1, 10, 1 >  translate < 10, 0, 0 > }//e
   object { CubeX1
            scale < 7.5, 1, 1 >  translate < 6.5,  5, 0 > }//etop
   object { CubeX1
            scale < 7.5, 1, 1 >  translate < 6.5, -5, 0 > }//ebot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end south frame east side union

// **************************************************************

//    DEFINE  french door frames: mock-ups=they don't open(yet):
#declare N_South_Frame_Doors =
union {
   object { CubeY1
            scale < 0.75, 10, 0.75 >  translate < -3, 0, 0 > }//left frame
   object { CubeY1
            scale < 0.75, 10, 0.75 >  translate <  0, 0, 0 > }//mid frame
   object { CubeY1
            scale < 0.75, 10, 0.75 >  translate <  3, 0, 0 > }//right frame
   object { CubeX1
            scale < 6, 0.75, 0.75 >  translate < 0,  5, 0 > }//top
   object { CubeX1
            scale < 5, 0.75, 0.75 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { White_Tex }
   #else
      texture { T_Chrome_2C }
   #end
      } // end french door frames

// **************************************************************

//    DEFINE  north room: south wall, west frame:
#declare N_South_Frame_West =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -7.5, 0, 0 > }//w
   object { CubeY1
            scale < 1, 10, 1 >  translate <    0, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  7.5, 0, 0 > }//e
   object { CubeX1
            scale < 15.5, 1, 1 >  translate < 0,  5, 0 > }//top
   object { CubeX1
            scale < 15.5, 1, 1 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end south frame west side

// **************************************************************

//    DEFINE  north room: south walls:
#declare N_South_Panel=
union {
   object {
      #declare RB_P1 = <  4.5,  11,  1.1 >; // right upper rear corner
      #declare RB_P2 = < -4.5, -11, -1.1 >; // left lower front corner
      #declare RB_Thickness = 2;      
      #declare RB_Solid = 1;          
      #include "roundbox.inc"
      translate < -0.5, 5, 0 >
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Stone15 scale < 5, 2, 1.5 > }
   #end
          } // end west panels
  //bathroom window:
  object { Panel_D1 scale < 1.2, 1.1, 0.05 > translate <  7, 10, 0 >
                    texture { T_MBH_Glass3 } } //w up
  object { Panel_D1 scale < 1.2, 1.1, 0.05 > translate <  7,  0, 0 >
                    texture { T_Glass1 } } //w down
  union {
    //french doors:
    object { Panel_D1 scale < 1.1, 1, 0.05 > translate < 34.5, 10, 0 > } //w
    object { Panel_D1 scale < 1.0, 1, 0.05 > translate < 52.5, 10, 0 > } //e
    texture { T_Glass1 }
        }//end clear glass:around chimney
      } // end union south wall panels
 
// **************************************************************

//    DEFINE  north room: south wall, center foyer, doorway:
#declare N_South_Frame_Center =
union {
   //middle section:
   object { Arch_Z2 scale < 10, 10, 1 >  translate < 0, -5, 0 > }
   object { CubeY1
            scale < 1.5, 20, 1.5 >  translate < -10, -5, 0 > }//w rear
   object { CubeY1
            scale < 1.5, 20, 1.5 >  translate <  10, -5, 0 > }//e rear
   object { CubeX1
            scale < 20.5, 1.5, 1.5 >  translate < 0,  5,   0 > }//rear top
   object { CubeX1
            scale < 20.5, 1.5, 1.5 >  translate < 0, -5,   0 > }//rear bot 
   object { CubeX1
            scale < 20.5, 1.5, 1.5 >  translate < 0,  5, -10 > }//front top
   object { CubeX1
            scale < 20.5, 1.5, 1.5 >  translate < 0, -5, -10 > }//front bot
   //east section:
   object { CubeY1
            scale < 1.5, 10, 1.5 >  translate < 10,  0, -10 > }//se
   object { CubeZ1
            scale < 1.5, 1.5, 10.5 >  translate < 10,  5,  -5 > }//top
   object { CubeZ1
            scale < 1.5, 1.5, 10.5 >  translate < 10, -5,  -5 > }//bot
   //west section:
   object { CubeY1
            scale < 1.5, 10, 1.5 >  translate < -10,  0, -10 > }//sw
   object { CubeZ1
            scale < 1.5, 1.5, 10.5 >  translate < -10,  5,  -5 > }//top
   object { CubeZ1
            scale < 1.5, 1.5, 10.5 >  translate < -10, -5,  -5 > }//bot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end union south side center, upper frames

// **************************************************************

//    DEFINE  north room: south wall, foyer panels above and below:
#declare N_South_Panel_Center =
union {
   //roof:
   object { Pane_Square_2
            rotate x*90
            scale < 21, 0.5, 10 >
            translate < 0, 5, -5 >
          }//end overhead window
   //upper:
   object { Pane_Square_2
            scale < 20, 10, 0.05 >
            translate < 0, 0, 0 >
          }//end center rear window pane
   object { Pane_Square_2
            scale < 20, 10, 0.05 >
            translate < 0, 0, -10 >
          }//end center front window pane
   //east side:
   object { Pane_Square_2
            rotate y*90
            scale < 0.05, 10, 10 >
            translate < 10, 0, -5 >
          }//end east window pane
   object { Pane_Square_2
            rotate y*90
            scale < 0.05, 10, 10 >
            translate < -10, 0, -5 >
          }//end west window pane
   object { Pane_Square_2
            rotate y*90
            scale < 0.05, 10, 10 >
            translate < -10, -10, -5 >
          }//end west window pane
   object { Pane_Square_2
            rotate y*90
            scale < 0.05, 10, 10 >
            translate < 10, -10, -5 >
          }//end east window pane
   //lower:
   object { Frame_D2
            translate < -7.5, -10, 0 >
            #if ( ShowDetails = 0 )
               texture { Coral_Tex }
            #else
               texture { T_Wood2 scale < 2, 4, 2 > }
            #end
          }//end lower west frame
   object { Pane_Square_2
            scale < 5, 10, 0.05 >
            translate < -7.5, -10, 0 >
          }//west of door
   object { Frame_D2
            translate < 7.5, -10, 0 >
            #if ( ShowDetails = 0 )
               texture { Coral_Tex }
            #else
               texture { T_Wood2 scale < 2, 4, 2 > }
            #end
          }//end lower east frame
   object { Pane_Square_2
            scale < 5, 10, 0.05 >
            translate < 7.5, -10, 0 >
          }//east of door
      } // end union south center foyer panels

// **************************************************************

//    DEFINE  north room: east wall frame:
#declare N_East_Frame =
union {
   object { rotated_Frame_A  translate < 0, 0, -12.5 > }
   object { rotated_Frame_A  translate < 0, 0,  12.5 > }
   object { CubeZ1
            scale < 1, 1, 15.5 >  translate < 0,  5, 0 > }//top
   object { CubeZ1
            scale < 1, 1, 15.5 >  translate < 0, -5, 0 > }//bot
   object { CubeY1
            scale < 2, 20, 2 >  translate < 0, -5, -17.5 > }//to ground floor
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end east frame union

// **************************************************************

//   DEFINE  a railing section:
#declare N_East_Railing =
object {
   Railing_Section_A ( 2, 0.25, 7 )
   rotate y*90
       } // end east interior railing

// **************************************************************

//    DEFINE  north room: east wall panels:
#declare N_East_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  1.1,  6.5,  18 >;  // right upper rear corner
         #declare RB_P2 = < -1.1, -6.5, -18 >;  // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"                
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.5,  13.5 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -4.5, -13.5 >; // left lower front corner
         #include "roundbox.inc"                
         translate < 0, 1, 0 >
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Coral_Tex }
      #else
         texture { T_Stone15 scale < 5, 2, 1.5 > }
      #end
              }//end difference
   #if ( ShowGlass = 1 )
      object { Pane_Square_2  rotate y*90  scale < 0.05, 10, 26.5 > }
   #end
      } // end east panel union

// **************************************************************

//    DEFINE  north room: west wall frame:
#declare N_West_Frame =
union {
   object { CubeY1  
            scale < 1.0, 10, 1.0 >  translate < 0, 0, 17.5 > }//n
   object { CubeY1  
            scale < 1.5, 10, 1.5 >  translate < 0, 0,  7.5 > }//
//   object { CubeY1  
//            scale < 1, 10, 1 >  translate < 0, 0,   4.5 > }//
   //west chimney goes (WENT!) here...
   object { CubeY1  
            scale < 1.5, 10, 1.5 >  translate < 0, 0,  -7.5 > }//
   object { CubeY1  
            scale < 1.0, 10, 1.0 >  translate < 0, 0, -17.5 > }//s
   object { CubeZ1
            scale < 1, 1, 35.5 >  translate < 0,  5, 0 > }//top
   object { CubeZ1
            scale < 1, 1, 35.5 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Coral_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } //end west frame union

// **************************************************************

//    DEFINE  north room: west wall panels:
#declare N_West_Panel =
union {
   object {
      #declare RB_P1 = <  1.1,  6.0,  6 >;  // right upper rear corner
      #declare RB_P2 = < -1.1, -6.0, -6 >;  // left lower front corner
      #declare RB_Thickness = 2;      
      #declare RB_Solid = 1;          
      #include "roundbox.inc"
      translate < 0, 6, -13 >
      #if ( ShowDetails = 0 )
         texture { Coral_Tex }
      #else
         texture { T_Stone15 scale < 4, 2, 1.5 > }
      #end
          }//end upper southern panel
   object {
      #declare RB_P1 = <  1.1,  6.0,  6 >;  // right upper rear corner
      #declare RB_P2 = < -1.1, -8.0, -6 >;  // left lower front corner
      #declare RB_Thickness = 2;      
      #declare RB_Solid = 1;          
      #include "roundbox.inc"                
      translate < 0, 6, 13 >
      #if ( ShowDetails = 0 )
         texture { Coral_Tex }
      #else
         texture { T_Stone15 scale < 4, 2, 1.5 > }
      #end
          }//end upper northern panel

   object { DoorA1_Closed rotate y*90  translate < 0, -5, 12.5 > } //west

   #if ( ShowGlass = 1 )
      //big, 2 story, middle window:
      object { Pane_Square_2  rotate y*90
                              scale < 0.05, 20, 15 > 
                              translate < 0, 1, 0 > } 
      //window, north of door:
      object { Pane_Square_2  rotate y*90
                              scale < 0.05, 8, 2.9 > 
                              translate < 0, -5, 16 > }//end n window
      //window, south of door:
      object { Pane_Square_2  rotate y*90
                              scale < 0.05, 8, 2.9 > 
                              translate < 0, -5, 9 > }//end s window
   #end
      } // end west panel union

// **************************************************************
//    DEFINE   a bathroom:
// **************************************************************

#declare Bathroom_1 =
union {
   //north frames:
   union {
      object { CubeY1  
               scale < 1, 10, 1 >  translate <  7.5, 0, 5 > }//e
      object { CubeY1  
               scale < 1, 10, 1 >  translate < -7.5, 0, 5 > }//w
      object { CubeX1
               scale < 15.5, 1, 1 >  translate < 0, 5, 5 > }//top
      #if ( ShowDetails = 0 )
         texture { Red_Tex }
      #else
         texture { T_Wood2 scale < 2, 4, 2 > }
      #end
         }//end frames

   //wall: facing north:
   difference {
      box { < -7.6, -5.0, -0.125 > <  7.6, 5.0, 0.125 > }
      box { <  4.0, -5.0, -1.000 > <  7.0, 2.0, 1.000 > }
      translate < 0, 0, 5 > 
      #if ( ShowDetails = 0 )
         texture { DarkWood_Tex }
      #else
         texture { T_Wood2  scale < 4, 8, 1 > }
      #end
              }//end north wall

   //door:
   object { DoorA2  translate < 5.5, -1.5, 5 > }

   //panel: water heater/plumping:
   object { Build_Block_1
            scale < 15.5, 2.5, 10 >
            translate < 0, 4, 0 >
            #if ( ShowDetails = 0 )
               texture { Blue_Tex }
            #else
               texture { T_Wood2  scale < 8, 4, 1 > }
            #end
          }//end water tank

   //ceiling lights:
   #if ( ShowLights = 0 )
      object { Flat_Light  translate <  3, 2.7,  3 > }
      object { Flat_Light  translate < -3, 2.7,  3 > }
      object { Flat_Light  translate <  3, 2.7, -3 > }
      object { Flat_Light  translate < -3, 2.7, -3 > }
   #else
      object { Lamp_B  translate <  3, 2.7,  3 > }
      object { Lamp_B  translate < -3, 2.7,  3 > }
      object { Lamp_B  translate <  3, 2.7, -3 > }
      object { Lamp_B  translate < -3, 2.7, -3 > }
   #end

   //drop ceiling:
   object { Build_Block_1
            texture { White_Tex }
            scale < 15.5, 0.25, 10 >
            translate < 0, 2.75, 0 >
          }//end drop ceiling

   //wall: facing east:
   box { < -0.25, -5, -5.0 > < 0.25, 5, 5.0 >
   translate < 7.5, 0, 0 >
      #if ( ShowDetails = 0 )
         texture { Green_Tex }
      #else
         texture { T_Wood2  scale < 4, 8, 1 > }
      #end
       }//end east wall

   //sink:
   object {
      box { < -3, -1.75, -1.25 > < 3, 1.75, 1.25 >
      #if ( ShowDetails = 0 )
         texture { Blue_Tex }
      #else
         texture { Blue_Tex }//change later! <<
      #end }//end box
      translate < -1, -3, 3.5 >
       }//end sink

   //toilet:
   union {
      box { < -1, -0.3, 0.15 > < 1, 1, 1.2 > }
      cylinder { -0.2*y, -1.3*y,  1 }
      #if ( ShowDetails = 0 )
         texture { Green_Tex }
      #else
         texture { Green_Tex }//change later! <<
      #end
      translate < -5.1, -3.5, 3.5 >
         }// end union toilet

   //shower:
   object {
      difference {
         box { < -2.5, -4.0, -2.5 > < 2.5, 4.0, 2.5 > }//end outer box
         box { < -2.4, -4.0, -2.4 > < 2.4, 3.8, 2.7 > }//end inner box
                 }//end diff.
      #if ( ShowDetails = 0 )
         texture { Orchid_Tex }
      #else
         texture { T_Glass1 }
      #end
      translate < -4.5, -1.3, -2.4 >
       }//end shower stall

   //tub:
   object {
      difference {
      object {
         #declare RB_P1 = <  5,  1.5,  2 >; // right upper rear corner
         #declare RB_P2 = < -5, -1.5, -2 >; // left lower front corner
         #include "roundbox.inc"              // calls file
             }//end body of tub
      object {
         #declare RB_P1 = <  4,  2.0,  1.5 >; // right upper rear corner
         #declare RB_P2 = < -4, -1.0, -1.5 >; // left lower front corner
         #include "roundbox.inc"              // calls file
             }//end basin of tub
      #if ( ShowDetails = 0 )
         texture { Yellow_Tex }
      #else
         texture { Yellow_Tex }//change later! <<
      #end
                 }//end diff.
      translate < 2.5, -3.6, -2.5 >
          } // end tub
/*
   //plumbing:
   object {
      PostY1 scale < 0.5, 10, 0.5 >
      translate < -5.2, 1, 5 >
      texture { Blue_Tex }
          }//end toilet plumbing
   object {
      PostY1 scale < 0.5, 7, 0.5 >
      translate < -1, 2.5, 4.8 >
      texture { Orange_Tex }
          }//end sink plumbing
   object {
      PostZ1 scale < 1, 1, 8 >
      translate < -5.5, -5.2, 1 >
      texture { Yellow_Tex }
          }//end shower plumbing
   object {
      PostY1 scale < 1, 11, 1 >
      translate < -5.5, -10, 5 >
      texture { Yellow_Tex }
          }//end shower plumbing
*/
        } // end bathroom

// **************************************************************
//     more North Room components...con't...
// **************************************************************

// *******************************************************************
//       C.  East Room:
// *******************************************************************

//    DEFINE  east room roof:
#declare East_Roof =
union {
   object {
      #declare RB_P1 = <  25.0,  1.05,  15 >;  // right upper rear corner
      #declare RB_P2 = < -24.0, -1.05, -10 >;  // left lower front corner
      #include "roundbox.inc"
      translate < 2, 0, 27 > 
         }//end north section roof
   object {
      #declare RB_P1 = <  8,  1.05,  20 >;  // right upper rear corner
      #declare RB_P2 = < -6, -1.05, -20 >;  // left lower front corner
      #include "roundbox.inc"
      translate < 19, 0, 0 > 
         }//end east section roof
   object {
      #declare RB_P1 = <  25.0,  1.05,  13 >;  // right upper rear corner
      #declare RB_P2 = < -22.0, -1.05, -15 >;  // left lower front corner
      #include "roundbox.inc"
      translate < 2, 0, -28 > 
         } // end south section roof
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone24 scale < 1.5, 2, 4 > }
      #end

      } // end union east wing roof

// **************************************************************

//    DEFINE East room, north panel:
#declare E_North_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  21,  6.5,  1.1 >;  // right upper rear corner
         #declare RB_P2 = < -21, -6.5, -1.1 >;  // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  16,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -16, -4.0, -2.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone15 scale < 1.5, 2, 4 > }
      #end
              }//end difference
   #if ( ShowGlass = 1 )
      object { Pane_Square_2 scale < 39, 10, 0.05 > }//center window
   #end
         }// end rear/north wall panels
 
// **************************************************************

//    DEFINE  East room, south (and north) wall frames:
#declare E_South_Frame =
union {
   object { CubeY1
            scale < 1, 10, 1 >  translate < -20, 0, 0 > }//w
   object { CubeY1
            scale < 1, 10, 1 >  translate < -11, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  11, 0, 0 > }
   object { CubeY1
            scale < 1, 10, 1 >  translate <  20, 0, 0 > }//e
   object { CubeX1
            scale < 39.5, 1, 1 >  translate < 0,  5, 0 > }//top
   object { CubeX1
            scale < 39.5, 1, 1 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Magenta_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      }// end south frame union 

// **************************************************************

//    DEFINE East room, south (and north) panel:
#declare E_South_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  20.5,  6.5,  1.1 >;  // right upper rear corner
         #declare RB_P2 = < -20.5, -6.5, -1.1 >;  // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  16,  4.0,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -16, -4.0, -2.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone15 scale < 1.5, 2, 4 > }
      #end
              }//end difference
   #if ( ShowGlass = 1 )
      object { Pane_Square_2 scale < 38, 10, 0.05 > }//center window
   #end
         }// end front/south wall panels
 
// **************************************************************

//    DEFINE  East room, east frames:
#declare E_East_Frame =
union {
   object { rotated_Frame_A  translate < 0, 0,  0 > }
   object { rotated_Frame_A  translate < 0, 0, 10 > }
   object { rotated_Frame_A  translate < 0, 0, 20 > }
   object { rotated_Frame_A  translate < 0, 0, 44 > }
   object { rotated_Frame_A  translate < 0, 0, 54 > }
   object { rotated_Frame_A  translate < 0, 0, 64 > }
   #if ( ShowDetails = 0 )
      texture { Magenta_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      }// end east wall union 

// **************************************************************

//    DEFINE  east room: east wall panels:
#declare E_East_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  1.1,  6.5,  18 >; // right upper rear corner
         #declare RB_P2 = < -1.1, -6.5, -18 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.0,  11.5 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -3.5, -11.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone15 scale < 2, 2, 4 > }
      #end
      translate z*20
              }//end difference north
   difference {
      object {
         #declare RB_P1 = <  1.1,  6.5,  18.5 >; // right upper rear corner
         #declare RB_P2 = < -1.1, -6.5, -18.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.0,  11 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -3.5, -11 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone15 scale < 2, 2, 4 > }
      #end
      translate z*-20
              }//end difference south
   object {
      object {
         #declare RB_P1 = <  1.1,  6.5,  8 >;  // right upper rear corner
         #declare RB_P2 = < -1.1, -6.5, -8 >;  // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end center panel
      #if ( ShowDetails = 0 )
         texture { Magenta_Tex }
      #else
         texture { T_Stone15 scale < 2, 2, 4 > }
      #end
          }//end middle panel

   #if ( ShowGlass = 1 )
      object { Pane_Square_2
               rotate y*90 scale < 0.05, 11, 25 > translate z*20 }
      object { Pane_Square_2
               rotate y*90 scale < 0.05, 11, 25 > translate z*-20 }
   #end
      } // end east window panel union

// **************************************************************

//    DEFINE  East room, west frames:
#declare E_West_Frame_N =
union {
   object { CubeY1
            scale < 1.5, 10, 1.5 >  translate < 0, 0, -15.5 > }//mid
   object { CubeY1
            scale < 1.0, 10, 1.0 >  translate < 0, 0,  15.5 > }//n
   object { CubeZ1
            scale < 1, 1, 30.5 >  translate < 0,  5, 0 > }//top
   object { CubeZ1
            scale < 1, 1, 30.5 >  translate < 0, -5, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Magenta_Tex }
   #else
      texture { T_Wood2  scale < 2, 2, 4 > }
   #end
      } // end west wall union 

// **************************************************************

//    DEFINE  East room, west panels:
#declare E_West_Panel_N =
union {
   difference {
      object {
         #declare RB_P1 = <  1.1,  6.5,  11.5 >; // right upper rear corner
         #declare RB_P2 = < -1.1, -6.5, -11.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.0,  6.5 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -3.0, -6.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
   #if ( ShowDetails = 0 )
      texture { Magenta_Tex }
   #else
      texture { T_Stone15 scale < 2, 2, 4 > }
   #end
              }//end difference 

//   #if ( ShowGlass = 1 )
      object { Pane_Square_2  rotate y*90  scale < 0.05, 9, 14 > }
//   #end
      } // end north portion, west panel

// **************************************************************

#declare E_West_Panel_S =
object { 
   Pane_Square_2  rotate y*90  scale < 0.005, 12.5, 30 >
       } // end southern part, west panel 

// **************************************************************
//       more East Room components, con't...
// **************************************************************

// *******************************************************************
//       D.  West Room: 
// *******************************************************************

//    DEFINE  West room roof:
#declare West_Roof =
object {
   #declare RB_P1 = <  16,  1.05,  17 >;  // right upper rear corner
   #declare RB_P2 = < -21, -1.05, -19 >;  // left lower front corner
   #include "roundbox.inc"
   #if ( ShowDetails = 0 )
      texture { Green_Tex }
   #else
      texture { T_Stone24  scale < 4, 2, 1.5 > }
   #end
      } // end west roof

// **************************************************************

//    DEFINE  West room: north wall frames:
#declare W_North_Frame =
union {
   object { CubeY1
            scale < 1, 12, 1 >  translate < -15, 0, 0 > }//w
   object { CubeY1
            scale < 1, 12, 1 >  translate < -11, 0, 0 > }//w
   object { CubeY1
            scale < 1, 12, 1 >  translate <   0, 0, 0 > }//e
   object { CubeY1
            scale < 1, 12, 1 >  translate <   8, 0, 0 > }//mid e
   object { CubeY1
            scale < 1, 12, 1 >  translate <  15, 0, 0 > }//mid e
   object { CubeX1
            scale < 30.5, 1, 1 >  translate < 0,  6, 0 > }//top
   object { CubeX1
            scale < 30.5, 1, 1 >  translate < 0, -6, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Goldenrod_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end west room north frames

// **************************************************************

//    DEFINE  West room: north panel:
#declare W_North_Panel =
union {
   //solid panel w/ window hole:
   difference {
      object {
         #declare RB_P1 = <  16.0,  6.5,  1.01 >; // right upper rear corner
         #declare RB_P2 = < -11.0, -6.5, -1.01 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = < 12.0,  4.5,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -4.5, -2.0, -2.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Goldenrod_Tex }
      #else
         texture { T_Stone15 scale < 4, 2, 1.5 > }
      #end
              }//end difference
   //glass in windows:
   #if ( ShowGlass = 1 )
      object { Pane_Square_2
               scale < 17, 8, 0.05 >
               translate < 4, 1, 0 > 
             }//window
   #end // show windows?
      } // end west room north panels

// **************************************************************

//    DEFINE  West room: south wall frames:
#declare W_South_Frame =
union {
   object { CubeY1
            scale < 1, 12, 1 >  translate <  -15, 0, 0 > }//w
   object { CubeY1   
            scale < 1, 12, 1 >  translate < -8.0, 0, 0 > }
   object { CubeY1   
            scale < 1, 12, 1 >  translate <  8.0, 0, 0 > }
   object { CubeY1
            scale < 1, 12, 1 >  translate <   15, 0, 0 > }//e
   object { CubeX1
            scale < 30.5, 1, 1 >  translate < 0,  6, 0 > }//top
   object { CubeX1
            scale < 30.5, 1, 1 >  translate < 0, -6, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Goldenrod_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end west room south frames

// **************************************************************

//    DEFINE  West room: south panel:
#declare W_South_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  16,  6.5,  1.01 >;  // right upper rear corner
         #declare RB_P2 = < -16, -6.5, -1.01 >;  // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  14,  4.5,  2.5 >; // right upper rear corner
         #declare RB_P2 = < -14, -2.0, -2.5 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Goldenrod_Tex }
      #else
         texture { T_Stone15 scale < 4, 2, 1.5 > }
      #end
              }//end difference
   #if ( ShowGlass = 1 )
      object { Pane_Square_2
               scale < 30, 9, 0.05 >
               translate < 0, 0, 0 >    //  <<<<<<<<<<<<<<<
             }//center window
   #end                  
      } // end west room south panels

// **************************************************************

//    DEFINE  West room: west wall frames:
#declare W_West_Frame =
union {
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0,  12.5 > }//n
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0,   7 > }
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0,  -7 > }
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0, -12.5 > }//s
   object { CubeZ1
            scale < 1, 1, 25.5 >  translate < 0,  6, 0 > }//top
   object { CubeZ1
            scale < 1, 1, 25.5 >  translate < 0, -6, 0 > }//bot
   #if ( ShowDetails = 0 )
      texture { Goldenrod_Tex }
   #else
      texture { T_Wood2 scale < 2, 2, 4 > }
   #end
      } // end west room west frames

// **************************************************************

//    DEFINE  West room: west wall panels:
#declare W_West_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  1.01,  6.5,  13.5 >; // right upper rear corner
         #declare RB_P2 = < -1.01, -6.5, -13.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.0,  10 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -2.5, -10 >; // left lower front corner
         #include "roundbox.inc"
         translate < 0, 1, 0 >
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Goldenrod_Tex }
      #else
         texture { T_Stone15  scale < 1.5, 2, 4 > }
      #end
              }//end difference 
   #if ( ShowGlass = 1 )
      object { Pane_Square_2  rotate y*90  scale < 0.05, 10, 25 > }
   #end
      } // end west wall window panels

// **************************************************************

//    DEFINE  West room: east wall frames:
#declare W_East_Frame =
union {
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0, -12.5 > }//south
   object { CubeY1
            scale < 1, 12, 1 >  translate < 0, 0,   3.5 > }//north
   object { CubeZ1
            scale < 1, 1, 25.5 >  translate < 0, 6, 0 > }//top
   #if ( ShowDetails = 0 )
      texture { Goldenrod_Tex }
   #else
      texture { T_Wood2 scale < 2, 4, 2 > }
   #end
      } // end west room east frames

// **************************************************************

//    DEFINE  West room: east wall panels:
#declare W_East_Panel =
union {
   difference {
      object {
         #declare RB_P1 = <  1.01,  6.5,   4.0 >; // right upper rear corner
         #declare RB_P2 = < -1.01, -6.5, -13.5 >; // left lower front corner
         #declare RB_Thickness = 2;      
         #declare RB_Solid = 1;          
         #include "roundbox.inc"
             } // end panel
      object {
         #declare RB_P1 = <  2.5,  4.0,  1.5 >; // right upper rear corner
         #declare RB_P2 = < -2.5, -2.5, -11.0 >; // left lower front corner
         #include "roundbox.inc"
             } // end cut-out
      #if ( ShowDetails = 0 )
         texture { Goldenrod_Tex }
      #else
         texture { T_Stone15 scale < 1.5, 2, 4 >  }
      #end
              }//end difference 
   #if ( ShowGlass = 1 )
      object { Pane_Square_2  rotate y*90
                              scale < 0.05, 10, 13 >
                              translate z*-5 }
   #end
      } // end east wall window panel

// **************************************************************
// **************************************************************
//    DEFINE  Kitchen Fixtures:
// **************************************************************

//    DEFINE  a stove:
#declare Stove_1 =
union {
   //hood:
   intersection {
      box { < 5.85, 11.00,  1.00 > < -5.85,  6.00, -1.75 > } 
      plane { y, 1
              scale < 5, 5, 0.25 >
              rotate x*45
              translate y*0.3
            }//end plane
      #if ( ShowDetails = 0 )
         texture { Green_Tex }
      #else
         texture { T_Copper_3D }
      #end 
                }// end intersected  box
   //body:
   box { < 5.85, 1.75,  1.75 > < -5.85, -1.75, -1.75 >
         #if ( ShowDetails = 0 )
            texture { FireBrick_Tex }
         #else
            texture { T_Chrome_2C }
         #end }
   //vent stack:
   box { < 1.55, 11.5, -0.85 > < -1.55,  1.00, -1.75 >
         #if ( ShowDetails = 0 )
            texture { Blue_Tex }
         #else
            texture { T_Copper_3D }
         #end }
   //back panel:
   box { < 5.85, 7.00, -1.40 > < -5.85,  1.50, -1.70 >
         #if ( ShowDetails = 0 )
            texture { Red_Tex }
         #else
            texture { T_Chrome_2C }
         #end }
#if (ShowDetails = 1 )
   //oven doors:
   box { < 1.00, 1.00,  0.05 > < -1.00, -1.00, -0.05 > 
         translate < -4, 0.2, 1.75 >
         texture { Black_Tex } }
   box { < 1.00, 1.00,  0.05 > < -1.00, -1.00, -0.05 > 
         translate < -1, 0.2, 1.75 >
         texture { Black_Tex } }
   //utility drawers:
   box { < 1.70, 0.2, 0.05 > < -1.50, -0.2, -0.05 > 
         translate < 2.50,  1.0, 1.76 >
         texture { Black_Tex } }
   box { < 1.70, 0.2, 0.05 > < -1.50, -0.2, -0.05 > 
         translate < 2.50,  0.5, 1.76 >
         texture { Black_Tex } }
   box { < 1.70, 0.2, 0.05 > < -1.50, -0.2, -0.05 > 
         translate < 2.50, -0.0, 1.76 >
         texture { Black_Tex } }
   box { < 1.70, 0.2, 0.05 > < -1.50, -0.2, -0.05 > 
         translate < 2.50, -0.5, 1.76 >
         texture { Black_Tex } }
   //burners:
   disc { < 0, 0, 0 >  z, 0.5, 0.0
          rotate x*90
          translate < 1, 1.75, -0.3 > 
          texture { Black_Tex } }
   disc { < 0, 0, 0 >  z, 0.5, 0.0
          rotate x*90
          translate < 1, 1.75,  1.0 > 
          texture { Black_Tex } }
   disc { < 0, 0, 0 >  z, 0.4, 0.0
          rotate x*90
          translate < -1.5, 1.75, -0.3 > 
          texture { Black_Tex } }
   disc { < 0, 0, 0 >  z, 0.4, 0.0
          rotate x*90
          translate < -0.25, 1.75, -0.3 > 
          texture { Black_Tex } }
   disc { < 0, 0, 0 >  z, 0.4, 0.0
          rotate x*90
          translate < -1.5, 1.75, 1 > 
          texture { Black_Tex } }
   disc { < 0, 0, 0 >  z, 0.4, 0.0
          rotate x*90
          translate < -0.25, 1.75, 1 > 
          texture { Black_Tex } }
   //grills:
   box { < 1.4, 0.1, 1.4 > < -1.4, -0.1, -1.4 >
         translate < -4, 1.67, 0.2 >
         texture {Black_Tex} }
   box { < 1.1, 0.1, 1.4 > < -1.1, -0.1, -1.4 >
         translate <  4, 1.67, 0.2 >
         texture {Black_Tex} }
#end
   #if ( ShowLights = 1 )
      //hood lights:
      object { Lamp_A_On  translate <  4, 6, 0 > }
      object { Lamp_A_On  translate < -4, 6, 0 > }
   #end
      } // end stove

// **************************************************************
// **************************************************************

//    DEFINE  a table: 10x 0.5y 4.5z
#declare Table_1 =
union {
   //top:
   object {
      box { < 5, 0.20, 2.25 > < -5, -0.20, -2.25 > }
            #if ( ShowDetails = 0 )
               texture { Orchid_Tex }
            #else
               texture { T_Wood3 
                         scale < 3, 1, 2 >
                         rotate y*90 rotate x*8
                         finish { specular 0.3 
                                  roughness 1.0
                                  reflection 0.15 }
                       }//end tex
            #end 
          }//end table top
   //legs:
   union {                             
      object {
         box { < 0.20, 1.75, 0.20 > < -0.20, -1.75, -0.20 > }
               translate <  2.5, -1.75, -1.5 > }//right front
      object {
         box { < 0.20, 1.75, 0.20 > < -0.20, -1.75, -0.20 > }
               translate <  2.5, -1.75,  1.5 > }//right rear
      object {
         box { < 0.20, 1.75, 0.20 > < -0.20, -1.75, -0.20 > }
               translate < -2.5, -1.75, -1.5 > }//left front
      object {
         box { < 0.20, 1.75, 0.20 > < -0.20, -1.75, -0.20 > }
               translate < -2.5, -1.75,  1.5 > }//left rear
      #if ( ShowDetails = 0 )
         texture { Orchid_Tex }
      #else
         texture { T_Wood3 
                   scale < 1, 3, 2 >
                   rotate y*90 rotate x*8
                   finish { specular 0.3 
                            roughness 1.0
                            reflection 0.15 }
                 }//end tex
      #end 
         }// end union legs
   //feet:
   union {
      object { 
         box { < 2.50, 0.20, 0.20 > < -2.50, -0.20, -0.20 > }
               translate <  0.0, -3.35, 0.0 > }//center bottom foot
      object {
         box { < 2.50, 0.20, 0.20 > < -2.50, -0.20, -0.20 > }
               translate <  0.0, -0.45, 0.0 > }//center top foot
      object { 
         box { < 0.20, 0.20, 1.70 > < -0.20, -0.20, -1.70 > }
               translate <  2.5, -3.35, 0.0 > }//right foot
      object { 
         box { < 0.20, 0.20, 1.70 > < -0.20, -0.20, -1.70 > }
               translate < -2.5, -3.35, 0.0 > }//left foot
      object { 
         box { < 0.20, 0.20, 1.70 > < -0.20, -0.20, -1.70 > }
               translate <  2.5, -0.45, 0.0 > }//right foot
      object { 
         box { < 0.20, 0.20, 1.70 > < -0.20, -0.20, -1.70 > }
               translate < -2.5, -0.45, 0.0 > }//left foot
      #if ( ShowDetails = 0 )
         texture { Orchid_Tex }
      #else
         texture { T_Wood3 
                   scale < 2, 1, 3 >
                   rotate y*90 rotate x*8
                   finish { specular 0.3 
                            roughness 1.0
                            reflection 0.15 }
                 }//end tex
      #end 
         }// end union feet
     } // end union table

// **************************************************************
// **************************************************************

//    DEFINE  a hanging cabinet: 18x 4y 3z:
#declare Cabinet_1 =
object {
   box { < 9.0, 2.0, 1.5 > < -9.0, -2.0, -1.0 > }
   #if ( ShowDetails = 0 )
      texture { Blue_Tex }
   #else
      texture { T_Wood2 scale < 1, 3, 1 > }
   #end
       } // end cabinet 1

// **************************************************************
// **************************************************************

//    DEFINE  a counter: 12x 3y 3z:
#declare Counter_1 =
object {
   box { < 6.0, 1.5, 1.5 > < -6.0, -1.5, -1.5 > }
   texture { Coral_Tex }
       } // end counter 1

// **************************************************************

//    DEFINE  a counter: 3x 3.5y 12z:
#declare Counter_2 =
union {
   box { < 1.6, 1.74, 6.0 > < -1.6, -1.75, -6.0 >
         #if ( ShowDetails = 0 )
            texture { Orchid_Tex }
         #else
            texture { T_Wood2 scale < 1, 1, 5 > }
         #end }
   box { < 1.7, 1.75, 6.0 > < -1.7, 1.70, -6.0 >
         #if ( ShowDetails = 0 )
            texture { Black_Tex }
         #else
            texture { Spex }
         #end }
      } // end counter 2

// **************************************************************

//    DEFINE  a cylinder counter: 5x 3.5y 4.5z:
#declare Counter_3 =
union {
   object {
      cylinder { 1.74*y, -1.75*y, 2.20 }
         #if ( ShowDetails = 0 )
            texture { Violet_Tex }
         #else
            texture { T_Wood2 scale < 1, 5, 1 > }
         #end
          }//body
   object { 
      cylinder { 1.75*y, 1.70*y, 2.30 }
         #if ( ShowDetails = 0 )
            texture { Black_Tex }
         #else
            texture { Spex }
         #end
          }//top
      } // end union cyl counter 3

// **************************************************************

//    DEFINE  a counter: 12x 3.5y 12z:
#declare Counter_4 =
union {
   box { < 8.0, 1.74, 1.5 > < -8.0, -1.75, -1.5 >
         #if ( ShowDetails = 0 )
            texture { Yellow_Tex }
         #else
            texture { T_Wood2 scale < 1, 1, 5 > }
         #end }//body
   box { < 8.0, 1.75, 1.6 > < -8.0, 1.70, -1.6 >
         #if ( ShowDetails = 0 )
            texture { Black_Tex }
         #else
            texture { Spex }
         #end }//top
      } // end counter 4

// **************************************************************
// **************************************************************

//    DEFINE  a sink: 3x 3.5y 12z:
#declare Sink_1 =
union {
   box { < 1.6, 1.75, 6.0 > < -1.6, -1.75, -6.0 >
         #if ( ShowDetails = 0 )
            texture { White_Tex }
         #else
            texture { White_Tex }
         #end }//end box
   //over sink:
   object { Lamp_A_On  translate < -0.9, 8, 0 > }//end lamp
      } // end union sink

// **************************************************************
// **************************************************************

//    DEFINE a refrigerator:
#declare Frig_1 =
object {
   box { < 1.5, 3.5, 2.7 > < -1.5, -3.5, -2.7 > }
   texture { Blue_Tex }
       } // end frig

// **************************************************************
// **************************************************************

//    DEFINE  generic kitchen:
#declare W_Kitchen =
union {
   object { Table_1    translate <   3.0, 3.50,   8.5 > }
   object { Cabinet_1  translate <   7.5, 8.00, -13.0 > }//top south
   //prep area:
   object { Stove_1    translate <  -7.5, 1.75, -12.5 > }//sw corner
   object { Sink_1     translate < -15.0, 1.75,  -8.0 > }//west side
   object { Counter_2  translate <   0.0, 1.75,  -8.0 > }//center
   object { Counter_3  translate <   0.0, 1.75,  -2.5 > }//center
   object { Counter_2  translate <  15.0, 1.75,  -5.0 > }//east side
   object { Counter_4  translate <   9.0, 1.75, -12.5 > }//southeast 
   object { Frig_1     translate < -15.0, 3.50,  0.75 > }
      } // end kitchen fixtures

// **************************************************************
//     more West Room components...con't...
// **************************************************************

// *******************************************************************
// *******************************************************************
//  IV.   a Modernist/International Style House:
// *******************************************************************
// *******************************************************************

/*
#declare Modernist_Home =
union {

   object { North_Room }
   object { East_Room  translate <  25, 0,   0 > }
   object { West_Room  translate < -45, 0, -20 > }
   object { Front_SideWalk  translate < -5, 0.5, -27.5 > }
   object { Arched_Hall_1   translate < -5, 4, -27.5 > }
   object { Rear_SideWalk1             translate <   0.0, 0.5, 30.0 > } //north door
   object { Rear_SideWalk1 rotate y*90 translate < -40.0, 0.5, 13.5 > } //northwest door
   object { Rear_SideWalk1             translate < -55.5, 0.5,  5.0 > } //westwest door

   #if ( ShowShrubs = 1 )
      #include "m_scape.inc"           // landscaping
      #include "fktr01.inc"            // fake plastic trees
      //fake tree: east front:
      object { treex08  scale 0.6  translate < 41, -4, -43 > } 
      object { treex09  scale 0.7  translate < 35, -5, -44 > } 
      object { treex08  scale 0.6  translate < 27, -5, -41 > }
      object { treex09  scale 0.4  translate < 19, -3, -42 > }
      object { treex08  scale 0.5  translate < 14, -4, -44 > }

      //fake trees: west side:
      Planter_Box_3 (-63, 1, -30, 0, 0, 10, 3)
      object { treex02  scale < 1.3, 1.6, 1.3 >  translate < -72, 0,  -3 > } 
      object { treex02  scale < 1.2, 1.6, 1.2 >  translate < -72, 0, -39 > }
      object { treex16 scale <1,1.1,1> translate < -44, -1,  0 > } 
      object { treex17 scale <1,1.2,1> translate < -44,  0,  8 > } 
      object { treex18 scale <1,1.1,1> translate < -44, -1, 20 > }

      //west of north door:
      object { treex15 scale <1,1.1,1> translate < -13, -1, 38 > }
      object { treex14 scale <1,1.1,1> translate < -13, -1, 30 > }

      //fake tree: west front:
      object { treex05  scale 0.5  translate < -59, -3, -40 > }//w end 
      object { treex08  scale 0.6  translate < -51, -2, -42 > }
      object { treex07  scale 0.5  translate < -45, -3, -40 > }
      object { treex08  scale 0.5  translate < -39, -3, -39 > }
      object { treex06  scale 0.7  translate < -33, -4, -42 > }//e end

      //near front door:
      object { Planter_Box_2  translate < -22.5, 0.25, -26 > }
      object { treex02  scale <1.1, 2.5, 1.1> translate < -22.5, 0, -26 > }

      //fake tree: east side:
      Planter_Box_3 (50, 1, -35, 0, 0, 8, 10)
      object { treex02  scale < 1.20, 2.1, 1.20 >  translate <  57, 0,  35 > }
      object { treex02  scale < 1.25, 2.2, 1.25 >  translate <  57, 0,   0 > } 
      object { treex02  scale < 1.30, 1.9, 1.30 >  translate <  57, 0, -35 > }  

      //fake tree: far south:
      object { treex02  scale < 1.30, 1.5, 1.30 >  translate < -15, 0, -96 > }
      object { treex02  scale < 1.35, 1.2, 1.35 >  translate < -21, 0, -87 > } 
      object { treex02  scale < 1.40, 1.7, 1.40 >  translate < -24, 0, -95 > }  
   #end

      } // end union modernist house
*/

// *******************************************************************
// *******************************************************************
// M_HOME00.INC   (c) Michael Brendan Hurley   Winter 2000-Winter 2002
//    www.geocities.com/mbrendanh/                 mbhcgc@saber.net
// *******************************************************************
// *******************************************************************
